@@ -1,3 +1,4 @@
+require 'addressable/uri'
 require 'twitter/arguments'
 require 'twitter/cursor'
 require 'twitter/error'
@@ -7,6 +8,7 @@ require 'twitter/rest/utils'
 require 'twitter/tweet'
 require 'twitter/user'
 require 'twitter/utils'
+require 'uri'
 
 module Twitter
   module REST
@@ -14,7 +16,6 @@ module Twitter
       include Twitter::REST::Utils
       include Twitter::Utils
       MAX_USERS_PER_REQUEST = 100
-      URI_SUBSTRING = '://'.freeze
 
       # Returns all lists the authenticating or specified user subscribes to, including their own
       #
@@ -83,7 +84,6 @@ module Twitter
       def remove_list_member(*args)
         list_from_response_with_user('/1.1/lists/members/destroy.json', args)
       end
-      deprecate_alias :list_remove_member, :remove_list_member
 
       # List the lists the specified user has been added to
       #
@@ -206,7 +206,6 @@ module Twitter
       def add_list_members(*args)
         list_from_response_with_users('/1.1/lists/members/create_all.json', args)
       end
-      deprecate_alias :list_add_members, :add_list_members
 
       # Check if a user is a member of the specified list
       #
@@ -269,7 +268,6 @@ module Twitter
       def add_list_member(*args)
         list_from_response_with_user('/1.1/lists/members/create.json', args)
       end
-      deprecate_alias :list_add_member, :add_list_member
 
       # Deletes the specified list
       #
@@ -290,7 +288,6 @@ module Twitter
       def destroy_list(*args)
         list_from_response(:post, '/1.1/lists/destroy.json', args)
       end
-      deprecate_alias :list_destroy, :destroy_list
 
       # Updates the specified list
       #
@@ -330,7 +327,6 @@ module Twitter
       def create_list(name, options = {})
         perform_post_with_object('/1.1/lists/create.json', options.merge(name: name), Twitter::List)
       end
-      deprecate_alias :list_create, :create_list
 
       # Show the specified list
       #
@@ -388,7 +384,6 @@ module Twitter
       def remove_list_members(*args)
         list_from_response_with_users('/1.1/lists/members/destroy_all.json', args)
       end
-      deprecate_alias :list_remove_members, :remove_list_members
 
       # Returns the lists owned by the specified Twitter user
       #
@@ -407,8 +402,6 @@ module Twitter
       def owned_lists(*args)
         cursor_from_response_with_user(:lists, Twitter::List, '/1.1/lists/ownerships.json', args)
       end
-      deprecate_alias :lists_ownerships, :owned_lists
-      deprecate_alias :lists_owned, :owned_lists
 
     private
 
@@ -464,28 +457,24 @@ module Twitter
       #
       # @param hash [Hash]
       # @param list [Integer, String, URI, Twitter::List] A Twitter list ID, slug, URI, or object.
-      # @return [Hash]
-      def merge_list!(hash, list) # rubocop:disable MethodLength
+      def merge_list!(hash, list)
         case list
-        when Integer
-          hash[:list_id] = list
-        when String
-          if list[URI_SUBSTRING]
-            list = list.split('/')
-            hash[:slug] = list.pop
-            hash[:owner_screen_name] = list.pop
-          else
-            hash[:slug] = list
-          end
-        when URI
-          list = list.path.split('/')
-          hash[:slug] = list.pop
-          hash[:owner_screen_name] = list.pop
-        when Twitter::List
-          hash[:list_id] = list.id
-          merge_owner!(hash, list.user)
+        when Integer               then hash[:list_id] = list
+        when Twitter::List         then merge_list_and_owner!(hash, list)
+        when String                then merge_slug_and_owner!(hash, list)
+        when URI, Addressable::URI then merge_slug_and_owner!(hash, list.path)
         end
-        hash
+      end
+
+      def merge_slug_and_owner!(hash, path)
+        list = path.split('/')
+        hash[:slug] = list.pop
+        hash[:owner_screen_name] = list.pop unless list.empty?
+      end
+
+      def merge_list_and_owner!(hash, list)
+        merge_list!(hash, list.id)
+        merge_owner!(hash, list.user)
       end
 
       # Take an owner and merge it into the hash with the correct key
