@@ -24,8 +24,10 @@ module Twitter
       # @option options [String] :until Optional. Returns tweets generated before the given date. Date should be formatted as YYYY-MM-DD.
       # @option options [Integer] :since_id Returns results with an ID greater than (that is, more recent than) the specified ID. There are limits to the number of Tweets which can be accessed through the API. If the limit of Tweets has occured since the since_id, the since_id will be forced to the oldest ID available.
       # @option options [Integer] :max_id Returns results with an ID less than (that is, older than) or equal to the specified ID.
+      # @option options [Boolean] :include_entities The entities node will be disincluded when set to false.
       # @return [Twitter::SearchResults] Return tweets that match a specified query with search metadata
       def search(q, options = {})
+        options = options.dup
         options[:count] ||= MAX_TWEETS_PER_REQUEST
         request = Twitter::REST::Request.new(self, :get, '/1.1/search/tweets.json', options.merge(q: q))
         Twitter::SearchResults.new(request)
