@@ -4,8 +4,11 @@ require 'twitter/base'
 module Twitter
   class Size < Twitter::Base
     include Equalizer.new(:h, :w)
-    attr_reader :h, :resize, :w
-    alias_method :height, :h
-    alias_method :width, :w
+    # @return [Integer]
+    attr_reader :h, :w
+    # @return [String]
+    attr_reader :resize
+    alias height h
+    alias width w
   end
 end
