@@ -1,19 +1,6 @@
 module Twitter
   module Utils
-    class << self
-      def included(base)
-        base.extend(ClassMethods)
-      end
-    end
-
-    module ClassMethods
-      def deprecate_alias(new_name, old_name, &block)
-        define_method(new_name) do |*args|
-          warn "#{Kernel.caller.first}: [DEPRECATION] ##{new_name} is deprecated. Use ##{old_name} instead."
-          send(old_name, *args, &block)
-        end
-      end
-    end
+  module_function
 
     # Returns a new array with the concatenated results of running block once for every element in enumerable.
     # If no block is given, an enumerator is returned instead.
@@ -24,7 +11,6 @@ module Twitter
       return to_enum(:flat_pmap, enumerable) unless block_given?
       pmap(enumerable, &Proc.new).flatten(1)
     end
-    module_function :flat_pmap
 
     # Returns a new array with the results of running block once for every element in enumerable.
     # If no block is given, an enumerator is returned instead.
@@ -39,6 +25,5 @@ module Twitter
         enumerable.collect { |object| Thread.new { yield(object) } }.collect(&:value)
       end
     end
-    module_function :pmap
   end
 end
