@@ -1,10 +1,9 @@
 require 'helper'
 
 describe Twitter::GeoResults do
-
   describe '#each' do
     before do
-      @geo_results = Twitter::GeoResults.new(:result => {:places => [{:id => 1}, {:id => 2}, {:id => 3}, {:id => 4}, {:id => 5}, {:id => 6}]})
+      @geo_results = Twitter::GeoResults.new(result: {places: [{id: 1}, {id: 2}, {id: 3}, {id: 4}, {id: 5}, {id: 6}]})
     end
     it 'iterates' do
       count = 0
@@ -22,14 +21,13 @@ describe Twitter::GeoResults do
 
   describe '#token' do
     it 'returns a String when token is set' do
-      geo_results = Twitter::GeoResults.new(:result => {}, :token => 'abc123')
+      geo_results = Twitter::GeoResults.new(result: {}, token: 'abc123')
       expect(geo_results.token).to be_a String
       expect(geo_results.token).to eq('abc123')
     end
     it 'returns nil when token is not set' do
-      geo_results = Twitter::GeoResults.new(:result => {})
+      geo_results = Twitter::GeoResults.new(result: {})
       expect(geo_results.token).to be_nil
     end
   end
-
 end
