@@ -1,10 +1,9 @@
 require 'helper'
 
 describe Twitter::OEmbed do
-
   describe '#author_uri' do
     it 'returns a URI when the author_url is set' do
-      oembed = Twitter::OEmbed.new(:author_url => 'https://twitter.com/sferik')
+      oembed = Twitter::OEmbed.new(author_url: 'https://twitter.com/sferik')
       expect(oembed.author_uri).to be_an Addressable::URI
       expect(oembed.author_uri.to_s).to eq('https://twitter.com/sferik')
     end
@@ -16,7 +15,7 @@ describe Twitter::OEmbed do
 
   describe '#author_uri?' do
     it 'returns true when the author_url is set' do
-      oembed = Twitter::OEmbed.new(:author_url => 'https://twitter.com/sferik')
+      oembed = Twitter::OEmbed.new(author_url: 'https://twitter.com/sferik')
       expect(oembed.author_uri?).to be true
     end
     it 'returns false when the author_uri is not set' do
@@ -27,7 +26,7 @@ describe Twitter::OEmbed do
 
   describe '#author_name' do
     it 'returns the author name' do
-      oembed = Twitter::OEmbed.new(:author_name => 'Erik Michaels-Ober')
+      oembed = Twitter::OEmbed.new(author_name: 'Erik Michaels-Ober')
       expect(oembed.author_name).to eq('Erik Michaels-Ober')
     end
     it 'returns nil when not set' do
@@ -38,7 +37,7 @@ describe Twitter::OEmbed do
 
   describe '#cache_age' do
     it 'returns the cache_age' do
-      oembed = Twitter::OEmbed.new(:cache_age => '31536000000')
+      oembed = Twitter::OEmbed.new(cache_age: '31536000000')
       expect(oembed.cache_age).to eq('31536000000')
     end
     it 'returns nil when not set' do
@@ -49,11 +48,11 @@ describe Twitter::OEmbed do
 
   describe '#height' do
     it 'returns the height' do
-      oembed = Twitter::OEmbed.new(:height => 200)
+      oembed = Twitter::OEmbed.new(height: 200)
       expect(oembed.height).to eq(200)
     end
     it 'returns it as an Integer' do
-      oembed = Twitter::OEmbed.new(:height => 200)
+      oembed = Twitter::OEmbed.new(height: 200)
       expect(oembed.height).to be_an Integer
     end
     it 'returns nil when not set' do
@@ -64,7 +63,7 @@ describe Twitter::OEmbed do
 
   describe '#html' do
     it 'returns the html' do
-      oembed = Twitter::OEmbed.new(:html => '<blockquote>all my <b>witty tweet</b> stuff here</blockquote>')
+      oembed = Twitter::OEmbed.new(html: '<blockquote>all my <b>witty tweet</b> stuff here</blockquote>')
       expect(oembed.html).to eq('<blockquote>all my <b>witty tweet</b> stuff here</blockquote>')
     end
     it 'returns nil when not set' do
@@ -75,7 +74,7 @@ describe Twitter::OEmbed do
 
   describe '#provider_name' do
     it 'returns the provider_name' do
-      oembed = Twitter::OEmbed.new(:provider_name => 'Twitter')
+      oembed = Twitter::OEmbed.new(provider_name: 'Twitter')
       expect(oembed.provider_name).to eq('Twitter')
     end
     it 'returns nil when not set' do
@@ -86,7 +85,7 @@ describe Twitter::OEmbed do
 
   describe '#provider_uri' do
     it 'returns a URI when the provider_url is set' do
-      oembed = Twitter::OEmbed.new(:provider_url => 'http://twitter.com')
+      oembed = Twitter::OEmbed.new(provider_url: 'http://twitter.com')
       expect(oembed.provider_uri).to be_an Addressable::URI
       expect(oembed.provider_uri.to_s).to eq('http://twitter.com')
     end
@@ -98,7 +97,7 @@ describe Twitter::OEmbed do
 
   describe '#provider_uri?' do
     it 'returns true when the provider_url is set' do
-      oembed = Twitter::OEmbed.new(:provider_url => 'https://twitter.com/sferik')
+      oembed = Twitter::OEmbed.new(provider_url: 'https://twitter.com/sferik')
       expect(oembed.provider_uri?).to be true
     end
     it 'returns false when the provider_uri is not set' do
@@ -109,7 +108,7 @@ describe Twitter::OEmbed do
 
   describe '#type' do
     it 'returns the type' do
-      oembed = Twitter::OEmbed.new(:type => 'rich')
+      oembed = Twitter::OEmbed.new(type: 'rich')
       expect(oembed.type).to eq('rich')
     end
     it 'returns nil when not set' do
@@ -120,11 +119,11 @@ describe Twitter::OEmbed do
 
   describe '#width' do
     it 'returns the width' do
-      oembed = Twitter::OEmbed.new(:width => 550)
+      oembed = Twitter::OEmbed.new(width: 550)
       expect(oembed.width).to eq(550)
     end
     it 'returns it as an Integer' do
-      oembed = Twitter::OEmbed.new(:width => 550)
+      oembed = Twitter::OEmbed.new(width: 550)
       expect(oembed.width).to be_an Integer
     end
     it 'returns nil when not set' do
@@ -135,7 +134,7 @@ describe Twitter::OEmbed do
 
   describe '#uri' do
     it 'returns a URI when the url is set' do
-      oembed = Twitter::OEmbed.new(:url => 'https://twitter.com/twitterapi/status/133640144317198338')
+      oembed = Twitter::OEmbed.new(url: 'https://twitter.com/twitterapi/status/133640144317198338')
       expect(oembed.uri).to be_an Addressable::URI
       expect(oembed.uri.to_s).to eq('https://twitter.com/twitterapi/status/133640144317198338')
     end
@@ -147,7 +146,7 @@ describe Twitter::OEmbed do
 
   describe '#uri?' do
     it 'returns true when the url is set' do
-      oembed = Twitter::OEmbed.new(:url => 'https://twitter.com/twitterapi/status/133640144317198338')
+      oembed = Twitter::OEmbed.new(url: 'https://twitter.com/twitterapi/status/133640144317198338')
       expect(oembed.uri?).to be true
     end
     it 'returns false when the url is not set' do
@@ -158,7 +157,7 @@ describe Twitter::OEmbed do
 
   describe '#version' do
     it 'returns the version' do
-      oembed = Twitter::OEmbed.new(:version => '1.0')
+      oembed = Twitter::OEmbed.new(version: '1.0')
       expect(oembed.version).to eq('1.0')
     end
     it 'returns nil when not set' do
@@ -166,5 +165,4 @@ describe Twitter::OEmbed do
       expect(version).to be_nil
     end
   end
-
 end
