@@ -1,4 +1,3 @@
-# coding: utf-8
 require 'helper'
 
 describe Twitter::User do
@@ -24,6 +23,7 @@ describe Twitter::User do
     it 'returns a Time when created_at is set' do
       user = Twitter::User.new(id: 7_505_382, created_at: 'Mon Jul 16 12:59:01 +0000 2007')
       expect(user.created_at).to be_a Time
+      expect(user.created_at).to be_utc
     end
     it 'returns nil when created_at is not set' do
       user = Twitter::User.new(id: 7_505_382)
@@ -48,7 +48,7 @@ describe Twitter::User do
         {
           url: 'https://t.co/L2xIBazMPf',
           expanded_url: 'http://example.com/expanded',
-          display_url: 'example.com/expanded…',
+          display_url: 'example.com/expanded...',
           indices: [10, 33],
         },
       ]
@@ -70,7 +70,7 @@ describe Twitter::User do
         {
           url: 'https://t.co/L2xIBazMPf',
           expanded_url: 'http://example.com/expanded',
-          display_url: 'example.com/expanded…',
+          display_url: 'example.com/expanded...',
           indices: [10, 33],
         },
       ]
@@ -89,7 +89,7 @@ describe Twitter::User do
         {
           url: 'https://t.co/L2xIBazMPf',
           expanded_url: 'http://example.com/expanded',
-          display_url: 'example.com/expanded…',
+          display_url: 'example.com/expanded...',
           indices: [10, 33],
         },
       ]
@@ -342,7 +342,7 @@ describe Twitter::User do
 
   describe '#status' do
     it 'returns a Status when status is set' do
-      user = Twitter::User.new(id: 7_505_382, status: {id: 25_938_088_801})
+      user = Twitter::User.new(id: 7_505_382, status: {id: 540_897_316_908_331_009})
       expect(user.status).to be_a Twitter::Tweet
     end
     it 'returns nil when status is not set' do
@@ -350,7 +350,7 @@ describe Twitter::User do
       expect(user.status).to be_nil
     end
     it 'has a user' do
-      user = Twitter::User.new(id: 7_505_382, status: {id: 25_938_088_801})
+      user = Twitter::User.new(id: 7_505_382, status: {id: 540_897_316_908_331_009})
       expect(user.status.user).to be_a Twitter::User
       expect(user.status.user.id).to eq(7_505_382)
     end
@@ -358,7 +358,7 @@ describe Twitter::User do
 
   describe '#status?' do
     it 'returns true when status is set' do
-      user = Twitter::User.new(id: 7_505_382, status: {id: 25_938_088_801})
+      user = Twitter::User.new(id: 7_505_382, status: {id: 540_897_316_908_331_009})
       expect(user.status?).to be true
     end
     it 'returns false when status is not set' do
@@ -379,16 +379,6 @@ describe Twitter::User do
     end
   end
 
-  describe '#verified' do
-    it 'outputs a warning' do
-      user = Twitter::User.new(id: 7_505_382, verified: true)
-      warning = capture_warning do
-        expect(user.verified).to be true
-      end
-      expect(warning).to match(/\[DEPRECATION\] #verified is deprecated\. Use #verified\? instead\./)
-    end
-  end
-
   describe '#website' do
     it 'returns a URI when the url is set' do
       user = Twitter::User.new(id: 7_505_382, url: 'https://github.com/sferik')
@@ -400,7 +390,7 @@ describe Twitter::User do
         {
           url: 'https://t.co/L2xIBazMPf',
           expanded_url: 'http://example.com/expanded',
-          display_url: 'example.com/expanded…',
+          display_url: 'example.com/expanded...',
           indices: [0, 23],
         },
       ]
@@ -424,7 +414,7 @@ describe Twitter::User do
         {
           url: 'https://t.co/L2xIBazMPf',
           expanded_url: 'http://example.com/expanded',
-          display_url: 'example.com/expanded…',
+          display_url: 'example.com/expanded...',
           indices: [0, 23],
         },
       ]
@@ -443,7 +433,7 @@ describe Twitter::User do
         {
           url: 'https://t.co/L2xIBazMPf',
           expanded_url: 'http://example.com/expanded',
-          display_url: 'example.com/expanded…',
+          display_url: 'example.com/expanded...',
           indices: [0, 23],
         },
       ]
@@ -465,7 +455,7 @@ describe Twitter::User do
         {
           url: 'https://t.co/L2xIBazMPf',
           expanded_url: 'http://example.com/expanded',
-          display_url: 'example.com/expanded…',
+          display_url: 'example.com/expanded...',
           indices: [0, 23],
         },
       ]
